# Django AI Core

**Developer-focused package for implementing AI tooling into Django sites.**

Django AI Core provides core functionality for interacting with LLMs in your Django project, as well as optional modules for building AI-powered apps.

## TODO

-   Core:
    -   Logging for LLM requests
    -   Async/streaming support
-   Agents:
    -   Rate limiting
    -   Streaming responses
-   Index:
    -   Test different backends
    -   Docs
    -   Higher-level API?
-   Chat:
    -   Build Chat/RAG module with chat UI
-   MCP:
    -   Build MCP 'function' registry
